@@ -87,8 +87,14 @@ class CUPSCAU(object):
         :return: file path of generated CUPSCAU File
         """
         file_path = os.path.join('/tmp', self.filename)
-        self.file.to_csv(
-            file_path, sep=';', header=False, columns=columns, index=False, line_terminator=';\n',
-            compression=self.default_compression
-        )
+        kwargs = {'sep': ';',
+                  'header': False,
+                  'columns': columns,
+                  'index': False,
+                  'line_terminator': ';\n'
+                  }
+        if self.default_compression:
+            kwargs.update({'compression': self.default_compression})
+
+        self.file.to_csv(file_path, **kwargs)
         return file_path
