@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from mesures.dates import *
-from mesures.headers import F5D_HEADER as columns
+from mesures.headers import F5_HEADER as COLUMNS
 from mesures.parsers.dummy_data import DummyCurve
 from zipfile import ZipFile
 import os
@@ -16,13 +16,11 @@ DTYPES = {'cups': 'category',
           'r3':  'int64',
           'r4': 'int64',
           'method': 'category',
-          'firmeza': 'category',
-          'factura': 'category',
-          'res': 'category'}
+          'firmeza': 'category'}
 
 
 class F5(object):
-    def __init__(self, data, distributor=None, comer=None, compression='bz2'):
+    def __init__(self, data, distributor=None, comer=None, compression='bz2', columns=COLUMNS, dtypes=DTYPES):
         """
         :param data: list of dicts or absolute file_path
         :param distributor: str distributor REE code
@@ -31,6 +29,8 @@ class F5(object):
         """
         if isinstance(data, list):
             data = DummyCurve(data).curve_data
+        self.columns = columns
+        self.dtypes = dtypes
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'F5'
@@ -59,53 +59,50 @@ class F5(object):
 
     @property
     def filename(self):
+        filename = "{prefix}_{distributor}_{comer}_{measures_date}_{timestamp}.{version}".format(
+                prefix=self.prefix, distributor=self.distributor, comer=self.comer,
+                measures_date=self.measures_date[:10].replace('/', ''),
+                timestamp=self.generation_date.strftime(SIMPLE_DATE_MASK), version=self.version
+            )
         if self.default_compression:
-            return "{prefix}_{distributor}_{comer}_{measures_date}_{timestamp}.{version}.{compression}".format(
-                prefix=self.prefix, distributor=self.distributor, comer=self.comer,
-                measures_date=self.measures_date.strftime('%Y%m%d'), timestamp=self.generation_date.strftime('%Y%m%d'),
-                version=self.version, compression=self.default_compression
-            )
-        else:
-            return "{prefix}_{distributor}_{comer}_{measures_date}_{timestamp}.{version}".format(
-                prefix=self.prefix, distributor=self.distributor, comer=self.comer,
-                measures_date=self.measures_date.strftime('%Y%m%d'), timestamp=self.generation_date.strftime('%Y%m%d'),
-                version=self.version
-            )
+            filename += ".{compression}".format(compression=self.default_compression)
+        return filename
 
     @property
     def zip_filename(self):
         return "{prefix}_{distributor}_{comer}_{measures_date}_{timestamp}.zip".format(
             prefix=self.prefix, distributor=self.distributor, comer=self.comer,
-            measures_date=self.measures_date.strftime('%Y%m%d'), timestamp=self.generation_date.strftime('%Y%m%d')
+            measures_date=self.measures_date[:10].replace('/', ''),
+            timestamp=self.generation_date.strftime(SIMPLE_DATE_MASK)
         )
 
     @property
     def total(self):
-        return self.file['ai'].sum()
+        return int(self.file['ai'].sum())
 
     @property
     def ai(self):
-        return self.file['ai'].sum()
+        return int(self.file['ai'].sum())
 
     @property
     def ae(self):
-        return self.file['ae'].sum()
+        return int(self.file['ae'].sum())
 
     @property
     def r1(self):
-        return self.file['r1'].sum()
+        return int(self.file['r1'].sum())
 
     @property
     def r2(self):
-        return self.file['r2'].sum()
+        return int(self.file['r2'].sum())
 
     @property
     def r3(self):
-        return self.file['r3'].sum()
+        return int(self.file['r3'].sum())
 
     @property
     def r4(self):
-        return self.file['r4'].sum()
+        return int(self.file['r4'].sum())
 
     @property
     def cups(self):
@@ -121,10 +118,7 @@ class F5(object):
 
     def reader(self, filepath):
         if isinstance(filepath, str):
-            df = pd.read_csv(
-                filepath, sep=';', names=columns + ['res'],
-                dtype=DTYPES
-            )
+            df = pd.read_csv(filepath, sep=';', names=self.columns, dtype=self.dtypes)
         elif isinstance(filepath, list):
             df = pd.DataFrame(data=filepath)
         else:
@@ -132,13 +126,18 @@ class F5(object):
 
         if 'firmeza' not in df:
             df['firmeza'] = df['method'].apply(lambda x: 1 if x in (1, 3) else 0)
-        if 'factura' not in df:
-            df['factura'] = 'F0000000000'
+
+        df = df.groupby(['cups', 'timestamp', 'season', 'firmeza', 'method']).aggregate(
+            {'ai': 'sum', 'ae': 'sum', 'r1': 'sum', 'r2': 'sum', 'r3': 'sum', 'r4': 'sum'}
+        ).reset_index()
+
+        df['timestamp'] = df['timestamp'].apply(lambda x: x.strftime(DATETIME_HOUR_MASK))
+
         for key in ['ai', 'ae', 'r1', 'r2', 'r3', 'r4']:
             if key not in df:
                 df[key] = 0
             df[key] = df[key].astype('int32')
-        df = df[columns]
+        df = df[self.columns]
         return df
 
     def writer(self):
@@ -149,20 +148,26 @@ class F5(object):
         daymin = self.file['timestamp'].min()
         daymax = self.file['timestamp'].max()
         self.measures_date = daymin
-        #todo: get a zip filename without measures_date
+        # TODO get a zip filename without measures_date
         zipped_file = ZipFile(os.path.join('/tmp', self.zip_filename), 'w')
         while daymin <= daymax:
             di = daymin
-            df = daymin + timedelta(days=1)
+            df = (datetime.strptime(daymin, DATETIME_HOUR_MASK) + timedelta(days=1)).strftime(DATETIME_HOUR_MASK)
             self.measures_date = di
             dataf = self.file[(self.file['timestamp'] >= di) & (self.file['timestamp'] < df)]
-            dataf['timestamp'] = dataf['timestamp'].apply(lambda x: x.strftime('%Y/%m/%d %H:%M'))
-            filepath = os.path.join('/tmp', self.filename)
-            dataf.to_csv(
-                filepath, sep=';', header=False, columns=columns, index=False, line_terminator=';\n',
-                compression=self.default_compression
-            )
+            # dataf['timestamp'] = dataf['timestamp'].apply(lambda x: x.strftime(DATETIME_HOUR_MASK))
+            file_path = os.path.join('/tmp', self.filename)
+            kwargs = {'sep': ';',
+                      'header': False,
+                      'columns': self.columns,
+                      'index': False,
+                      'line_terminator': ';\n'
+                      }
+            if self.default_compression:
+                kwargs.update({'compression': self.default_compression})
+
+            dataf.to_csv(file_path, **kwargs)
             daymin = df
-            zipped_file.write(filepath, arcname=os.path.basename(filepath))
+            zipped_file.write(file_path, arcname=os.path.basename(file_path))
         zipped_file.close()
         return zipped_file.filename
